# SAPOFTO
**S**hane's **A**ll **P**urpose **O**rg **F**ile **T**ree **O**bject 

This project is an evolution on the OrgNode object from (https://github.com/shaneallcroft/orgutils )'s develop branch. The addition of SAPOFTO to orgutils would've clashed too much with the 0-dependency functional programming of the rest of the package, so instead it lives here now : )


Install it with
```
python -m pip install SAPOFTO
```